
// Oggetto che raccoglie le info necessarie per la pagina
pageInfo = {};

// Inizializzazione della pagina
initPage();


// Def. funzione di inizializzazione
async function initPage(){
  pageInfo = await getPageInfo();
  updatePage();
}

// Esegue le queries, restituisce un oggetto con tutte le info per completare la pagina
async function getPageInfo(){
  var out = {};

  try{
    out.queryPlace = await doJsonQuery(queryCountLuogo, true);
    out.queryTot = await doJsonQuery(queryCountDataset, true);
    out.querySupport = await doJsonQuery(querySupportCount, true);
    out.queryLemmmas = await doJsonQuery(querySupportLemma, true);
    
  } catch(err){
    console.log(err);
  }

  console.log('out', out)
  return out;
}


// Aggiorna la pagina usando l'oggetto-info passato come parametro
function updatePage(){

  var tot = pageInfo.queryTot.results.bindings[0].documenti.value;
  var occ = pageInfo.queryPlace.results.bindings[0].occorrenze.value;

  const listaMisure = [];

  for (var i=0; i<pageInfo.querySupport.results.bindings.length; i++) {
    support_count = pageInfo.querySupport.results.bindings[i].occorrenze.value;
    name = pageInfo.querySupport.results.bindings[i].antroponimo.value;
    freqAntroponimo = pageInfo.querySupport.results.bindings[i].count.value;
    var support = ((support_count/tot) * 100).toFixed(2) + '%';
    var confidence = ((support_count/occ) * 100).toFixed(2) + '%';
    var probBi = support_count/tot;
    var probPersona = freqAntroponimo/tot;
    var probabilityPersona = (probPersona * 100).toFixed(2) + '%';
    var probLuogo = occ/tot;
    var check = probPersona * probLuogo;
    var interest = probBi/check;
    var interesse = interest.toFixed(2);
    var correlazione = "";
    if (interest == 1) {
      correlazione = "Indipendenza";
    } 
    else if (interest > 1) {
      correlazione = "Positiva";
    }
    else {
      correlazione = "Negativa";
    }
    listaMisure.push([name, freqAntroponimo, probabilityPersona, support_count, support, confidence, interesse, correlazione]);
  }

  var thead = "<div class='row' id='thead_support'><div class='col first'>Antroponimo</div> \
  <div data-toggle='modal' data-target='#FrequenzaModal' class='col help'>Frequenza assoluta antroponimo</div> \
  <div class='col help' data-toggle='modal' data-target='#ProbabilityModal'>Probabilità Antroponimo</div> \
  <div class='col help' data-toggle='modal' data-target='#SupportCountModal'>Support Count</div> \
  <div class='col help' data-toggle='modal' data-target='#SupportModal'>Supporto</div> \
  <div class='col help' data-toggle='modal' data-target='#ConfidenzaModal'>Confidenza</div> \
  <div class='col help' data-toggle='modal' data-target='#InteresseModal'>Interesse</div> \
  <div class='col help' data-toggle='modal' data-target='#CorrelazioneModal'>Correlazione</div></div>";

  if (listaMisure.length > 1) {
      document.getElementById("my_supportList").innerHTML = thead + formatListAsGrid(listaMisure);
    } else {
      document.getElementById("my_supportList").innerHTML = "Dati insufficienti";
    }

  /*Supporto Lemmi*/

  const listaMisureLemmi = [];

  for (var i=0; i<pageInfo.queryLemmmas.results.bindings.length; i++) {
    support_count = pageInfo.queryLemmmas.results.bindings[i].occorrenze.value;
    name = pageInfo.queryLemmmas.results.bindings[i].lemma.value;
    freqLemma = pageInfo.queryLemmmas.results.bindings[i].count.value;
    var support = ((support_count/tot) * 100).toFixed(2) + '%';
    var confidence = ((support_count/occ) * 100).toFixed(2) + '%';
    var probBis = support_count/tot;
    var probLemma = freqLemma/tot;
    var probabilityLemma = (probLemma * 100).toFixed(2) + '%';
    var probLuogo = occ/tot;
    var check = probLemma * probLuogo;
    var interest = probBis/check;
    var interesse = interest.toFixed(2);
    var correlazione = "";
    if (interest == 1) {
      correlazione = "Indipendenza";
    } 
    else if (interest > 1) {
      correlazione = "Positiva";
    }
    else {
      correlazione = "Negativa";
    }
    listaMisureLemmi.push([name, freqLemma, probabilityLemma, support_count, support, confidence, interesse, correlazione]);
  }

  var theadL = "<div class='row' id='thead_lemmi'><div class='col first'>Lemma</div> \
    <div data-toggle='modal' data-target='#FrequenzaModal' class='col help'>Frequenza assoluta lemma</div> \
    <div class='col help' data-toggle='modal' data-target='#ProbabilityModal'>Probabilità Antroponimo</div> \
    <div class='col help' data-toggle='modal' data-target='#SupportCountModal'>Support Count</div> \
    <div class='col help' data-toggle='modal' data-target='#SupportModal'>Supporto</div> \
    <div class='col help' data-toggle='modal' data-target='#ConfidenzaModal'>Confidenza</div> \
    <div class='col help' data-toggle='modal' data-target='#InteresseModal'>Interesse</div> \
    <div class='col help' data-toggle='modal' data-target='#CorrelazioneModal'>Correlazione</div></div>";

  if (listaMisureLemmi.length > 1) {
      document.getElementById("my_supportList2").innerHTML = theadL + formatListAsGrid(listaMisureLemmi);
    } else {
      document.getElementById("my_supportList2").innerHTML = "Dati insufficienti";
    }

  /*if(pageInfo.titolo) document.getElementById("title").innerHTML = pageInfo.titolo.titolo.value;
  
  if(pageInfo.query1) {
    if(pageInfo.query1.hasOwnProperty('mittente')) document.getElementById("mittente_id").innerHTML = pageInfo.query1.mittente.value;
    if(pageInfo.query1.hasOwnProperty('destinatario')) document.getElementById("destinatario_id").innerHTML = pageInfo.query1.destinatario.value;
    if(pageInfo.query1.hasOwnProperty('luogo_partenza')) document.getElementById("luogo_partenza_id").innerHTML = pageInfo.query1.luogo_partenza.value;
    if(pageInfo.query1.hasOwnProperty('uriLuogoPartenza')) document.getElementById("luogo_partenza_btn").innerHTML = createButton("fa fa-map", "Vedi mappa", "schedaMappa('LUOGO')".replace("LUOGO", pageInfo.query1.uriLuogoPartenza.value));
    if(pageInfo.query1.hasOwnProperty('luogo_arrivo')) document.getElementById("luogo_arrivo_id").innerHTML = pageInfo.query1.luogo_arrivo.value;
    if(pageInfo.query1.hasOwnProperty('uriLuogoArrivo')) document.getElementById("luogo_arrivo_btn").innerHTML = createButton("fa fa-map", "Vedi mappa", "schedaMappa('LUOGO')".replace("LUOGO", pageInfo.query1.uriLuogoArrivo.value));
    if(pageInfo.query1.hasOwnProperty('data_partenza')) document.getElementById("data_partenza_id").innerHTML = pageInfo.query1.data_partenza.value;
    if(pageInfo.query1.hasOwnProperty('data_arrivo')) document.getElementById("data_arrivo_id").innerHTML = pageInfo.query1.data_arrivo.value;
    
  }

  if(pageInfo.query1){
    document.getElementById("mittente_id").innerHTML = pageInfo.query1.mittente.value;
    //document.getElementById("mittente_btn").innerHTML = createButton("fa fa-user", "Scheda persona", "schedaPersona('PERS')".replace("PERS", pageInfo.query1.mittente.value));
  }
  if(pageInfo.query1){
    document.getElementById("destinatario_id").innerHTML = pageInfo.query1.destinatario.value;
    //document.getElementById("destinatario_btn").innerHTML = createButton("fa fa-user", "Scheda persona", "schedaPersona('PERS')".replace("PERS", pageInfo.query1.destinatario.value));
  }
  if(pageInfo.query1){
    document.getElementById("imageASPO").innerHTML = createEmbed(pageInfo.query1.subject.value);
  }
  if(pageInfo.query1){
    document.getElementById("luogo_partenza_id").innerHTML = pageInfo.query1.luogo_partenza.value;
    document.getElementById("luogo_partenza_btn").innerHTML = createButton("fa fa-map", "Vedi mappa", "schedaMappa('LUOGO')".replace("LUOGO", pageInfo.query1.uriLuogoPartenza.value));
  }
  if(pageInfo.query1){
    document.getElementById("luogo_arrivo_id").innerHTML = pageInfo.query1.luogo_arrivo.value;
    document.getElementById("luogo_arrivo_btn").innerHTML = createButton("fa fa-map", "Vedi mappa", "schedaMappa('LUOGO')".replace("LUOGO", pageInfo.query1.uriLuogoArrivo.value));
  }
  if(pageInfo.query1) document.getElementById("data_partenza_id").innerHTML = pageInfo.query1.data_partenza.value;
  if(pageInfo.query1) document.getElementById("data_arrivo_id").innerHTML = pageInfo.query1.data_arrivo.value;
  
  if(pageInfo.descrizione) document.getElementById("descrizione_id").innerHTML = pageInfo.descrizione.descrizione.value;
  if(pageInfo.areaLinguistica) document.getElementById("lingua_id").innerHTML = pageInfo.areaLinguistica.lingua.value;
  if(pageInfo.areaLinguistica) document.getElementById("area_linguistica_id").innerHTML = pageInfo.areaLinguistica.area_linguistica.value;
  if(pageInfo.segnatura){
    document.getElementById("segnatura_id").innerHTML = pageInfo.segnatura.segnatura_OVI.value;
    document.getElementById("segnatura_btn").innerHTML = createButton("fa fa-link", "Link ASPO", "schedaASPO('SEGN')".replace("SEGN", thisUrlParams.link));
  }
  if(pageInfo.edizione){
    document.getElementById("edizione_id").innerHTML = pageInfo.edizione.edizione.value;
    document.getElementById("edizione_btn").innerHTML = createButton("fa fa-comments", "Cita Edizione", "schedaEdizione('EDIZ')".replace("EDIZ", pageInfo.edizione.edizione.value));
  }
  if(pageInfo.testo) document.getElementById("trascrizione_id").innerHTML = pageInfo.testo.testo_lemmatizzato.value;
  //
  if(pageInfo.antroponimi && pageInfo.antroponimi.length){
    const listaAntroponimi = pageInfo.antroponimi.map(elem => elem.antroponimo.value);
    document.getElementById("antroponimi").innerHTML = formatListAsLi(listaAntroponimi);
  }
  if(pageInfo.toponimi && pageInfo.toponimi.length){
    const listaToponimi = pageInfo.toponimi.map(elem => elem.toponimo.value);
    document.getElementById("toponimi").innerHTML = formatListAsLi(listaToponimi);
  }

  if(pageInfo.query2) {
    if(pageInfo.query2.hasOwnProperty('mittente')) document.getElementById("mittente_id_ASPO").innerHTML = pageInfo.query2.mittente.value;
    if(pageInfo.query2.hasOwnProperty('uriSender')) document.getElementById("mittente_btn_ASPO").innerHTML = createButton("fa fa-user", "Scheda persona", "schedaPersona('PERS')".replace("PERS", pageInfo.query2.uriSender.value));
    if(pageInfo.query2.hasOwnProperty('destinatario')) document.getElementById("destinatario_id_ASPO").innerHTML = pageInfo.query2.destinatario.value;
    if(pageInfo.query2.hasOwnProperty('uriReceiver')) document.getElementById("destinatario_btn_ASPO").innerHTML = createButton("fa fa-user", "Scheda persona", "schedaPersona('PERS')".replace("PERS", pageInfo.query2.uriReceiver.value));
    if(pageInfo.query2.hasOwnProperty('placeSend')) document.getElementById("luogo_partenza_id_ASPO").innerHTML = pageInfo.query2.placeSend.value;
    if(pageInfo.query2.hasOwnProperty('placeReceive')) document.getElementById("luogo_arrivo_id_ASPO").innerHTML = pageInfo.query2.placeReceive.value;
    if(pageInfo.query2.hasOwnProperty('timeSpanSend')) document.getElementById("data_partenza_id_ASPO").innerHTML = pageInfo.query2.timeSpanSend.value;
    if(pageInfo.query2.hasOwnProperty('timeSpanReceive')) document.getElementById("data_arrivo_id_ASPO").innerHTML = pageInfo.query2.timeSpanReceive.value;
    if(pageInfo.query2.hasOwnProperty('material')) document.getElementById("consistenzaASPO").innerHTML = pageInfo.query2.material.value;
    if(pageInfo.query2.hasOwnProperty('dimension')) document.getElementById("dimensioneASPO").innerHTML = pageInfo.query2.dimension.value;
    if(pageInfo.query2.hasOwnProperty('identifier')) document.getElementById("segnatura_id_ASPO").innerHTML = pageInfo.query2.identifier.value;
    if(pageInfo.query2.hasOwnProperty('currentLocation')) document.getElementById("ownerASPO").innerHTML = pageInfo.query2.currentLocation.value;
    
  }

  if(pageInfo.query1){
    document.getElementById("imageASPO").innerHTML = createEmbed(pageInfo.query1.subject.value);
  }*/
}

// Mini-utility per formattare liste
function formatListAsLi(thisList){
  toRet = "";
  thisList.forEach(value => toRet += "<li>" + value + "</li>");
  return toRet;
}

function formatListAsGrid(thisList){
  toRet = "";
  thisList.forEach(value => toRet += "<div class='row'>" + "<div class='col first'>" + value[0] + 
    "</div><div class='col'>" + value[1] + "</div><div class='col'>" + value[2] + "</div><div class='col'>" + value[3] + "</div><div class='col'>" + value[4] + "</div><div class='col'>" + value[5] + "</div><div class='col'>" + 
    value[6] + "</div><div class='col'>" + value[7] + "</div></div>");
  return toRet;
}


